@@ -78,38 +78,38 @@ class TestExamples(unittest.TestCase):
 
     def test_Xie_Ru0001_Example1_ND(self):
         lib = GroupLibrary.Load('XieGA2022')
-        descriptors = lib.GetDescriptors('[Ru]C([Ru])C([Ru])([Ru])C=O')
+        descriptors = lib.GetDescriptors('[Ru]C([Ru])C([Ru])([Ru])C')
         thermochem = lib.Estimate(descriptors, 'thermochem')
-        GroupDict = {'C(C)(H)(Ru)2': 1, 'C(C)(CO)(Ru)2': 1, 'CO(C)(H)': 1, 'CRu2CRu2': 1}
+        GroupDict = {'C(C)(H)(Ru)2': 1, 'C(C)2(Ru)2': 1, 'C(C)(H)3': 1, 'CRu2CRu2': 1}
         HoRT = thermochem.get_HoRT(500)
-        self.assertAlmostEqual(HoRT, -16.63461754058872)
+        self.assertAlmostEqual(HoRT, -35.040312149773726)
         self.assertEqual(descriptors, GroupDict)
 
     def test_Xie_Ru0001_Example1_Dim(self):
         lib = GroupLibrary.Load('XieGA2022')
-        descriptors = lib.GetDescriptors('[Ru]C([Ru])C([Ru])([Ru])C=O')
+        descriptors = lib.GetDescriptors('[Ru]C([Ru])C([Ru])([Ru])C')
         thermochem = lib.Estimate(descriptors, 'thermochem')
-        GroupDict = {'C(C)(H)(Ru)2': 1, 'C(C)(CO)(Ru)2': 1, 'CO(C)(H)': 1, 'CRu2CRu2': 1}
+        GroupDict = {'C(C)(H)(Ru)2': 1, 'C(C)2(Ru)2': 1, 'C(C)(H)3': 1, 'CRu2CRu2': 1}
         H = thermochem.get_H(500, 'kJ/mol')
-        self.assertAlmostEqual(H, -69.1539294147999)
+        self.assertAlmostEqual(H, -145.6706333743726)
         self.assertEqual(descriptors, GroupDict)
 
     def test_Xie_Ru0001_Example2_ND(self):
         lib = GroupLibrary.Load('XieGA2022')
-        descriptors = lib.GetDescriptors('C(=O)([Ru])O')
+        descriptors = lib.GetDescriptors('CCC')
         thermochem = lib.Estimate(descriptors, 'thermochem')
-        GroupDict = {'CO(O)(Ru)': 1, 'O(CO)(H)': 1}
+        GroupDict = {'C(C)(H)3': 2, 'C(C)2(H)2': 1}
         HoRT = thermochem.get_HoRT(500)
-        self.assertAlmostEqual(HoRT, -92.62100671375563)
+        self.assertAlmostEqual(HoRT, -41.49969417868688)
         self.assertEqual(descriptors, GroupDict)
 
     def test_Xie_Ru0001_Example2_Dim(self):
         lib = GroupLibrary.Load('XieGA2022')
-        descriptors = lib.GetDescriptors('C(=O)([Ru])O')
+        descriptors = lib.GetDescriptors('CCC')
         thermochem = lib.Estimate(descriptors, 'thermochem')
-        GroupDict = {'CO(O)(Ru)': 1, 'O(CO)(H)': 1}
+        GroupDict = {'C(C)(H)3': 2, 'C(C)2(H)2': 1}
         H = thermochem.get_H(500, 'kJ/mol')
-        self.assertAlmostEqual(H, -385.04681847852567)
+        self.assertAlmostEqual(H, -172.52376948049303)
         self.assertEqual(descriptors, GroupDict)
 
 
